module Data.Kind(Type, Constraint) where
import qualified Prelude()
import Primitives
